| Title: | Print Right-to-Left Languages Correctly |
|---|---|
| Description: | Convenience functions to make some common tasks with right-to-left string printing easier, more convenient and with no need to remember long Unicode characters. Specifically helpful for right-to-left languages such as Arabic, Persian and Hebrew. |
| Authors: | Matan Hakim [aut, cre, cph] (ORCID: <https://orcid.org/0009-0002-9372-8975>) |
| Maintainer: | Matan Hakim <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0.9000 |
| Built: | 2026-05-10 08:33:48 UTC |
| Source: | https://github.com/matanhakim/rtlr |
Wrap a string with RTL-embedding Unicode characters
str_rtl(..., multiline = FALSE)str_rtl(..., multiline = FALSE)
... |
One or more character vectors, ideally of length 1. |
multiline |
Whether to split the input strings to separate lines. Defaults to |
A character vector.
# Notice how the `.` prints to the right, while in RTL it should print to the left cat("a.") # `str_rtl()` fixes this: str_rtl("a.") |> cat() str_rtl("a.", "b.", multiline = TRUE) |> cat()# Notice how the `.` prints to the right, while in RTL it should print to the left cat("a.") # `str_rtl()` fixes this: str_rtl("a.") |> cat() str_rtl("a.", "b.", multiline = TRUE) |> cat()